@@ -24,7 +24,12 @@ const contentsPlugin: JupyterLiteServerPlugin<IContents> = {
       storageDrivers,
       localforage
     });
-    app.started.then(() => contents.initialize().catch(console.warn));
+    app.started.then(() =>
+      contents
+        .initialize()
+        .then(() => console.log('custom contents initialized'))
+        .catch(console.warn)
+    );
     return contents;
   }
 };
